diff --git a/applications/solvers/basic/potentialFoam/potentialFoam.C b/applications/solvers/basic/potentialFoam/potentialFoam.C
index 808b964e4fd1a5762155eedd5e5a82c540ce2fde..8e4a12ee0d01af803b9a615c0852547c76bc0e9e 100644
--- a/applications/solvers/basic/potentialFoam/potentialFoam.C
+++ b/applications/solvers/basic/potentialFoam/potentialFoam.C
@@ -105,7 +105,6 @@ int main(int argc, char *argv[])
 
     runTime.functionObjects().end();
 
-
     Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
         << "  ClockTime = " << runTime.elapsedClockTime() << " s"
         << nl << endl;
diff --git a/applications/utilities/parallelProcessing/decomposePar/domainDecomposition.C b/applications/utilities/parallelProcessing/decomposePar/domainDecomposition.C
index 36a6ad2eb4c10fe1ff21a4dc5f2c6af8a3465034..95a471844b69c22ef43bd6aebca7c7be9752e7ed 100644
--- a/applications/utilities/parallelProcessing/decomposePar/domainDecomposition.C
+++ b/applications/utilities/parallelProcessing/decomposePar/domainDecomposition.C
@@ -265,8 +265,8 @@ bool Foam::domainDecomposition::writeDecomposition()
             Time::controlDictName,
             time().rootPath(),
             processorCasePath,
-            "system",
-            "constant"
+            word("system"),
+            word("constant")
         );
         processorDb.setTime(time());
 
diff --git a/etc/config/paraview.csh b/etc/config/paraview.csh
index 9b4f9137aa8a05dd4914a07e9a60db670b3af401..86a5287904541d94a20f57259fe78bc585487c2a 100644
--- a/etc/config/paraview.csh
+++ b/etc/config/paraview.csh
@@ -80,7 +80,7 @@ case [0-9]*:
 endsw
 
 
-set paraviewInstDir=$WM_THIRD_PARTY_DIR/paraview-${ParaView_VERSION}
+set paraviewInstDir=$WM_THIRD_PARTY_DIR/ParaView-${ParaView_VERSION}
 setenv ParaView_DIR $WM_THIRD_PARTY_DIR/platforms/$WM_ARCH$WM_COMPILER/paraview-${ParaView_VERSION}
 
 # set paths if binaries or source are present
diff --git a/etc/config/paraview.sh b/etc/config/paraview.sh
index 331f3092dd5f3f851ef612dd51269d0c18678ecf..9ffd68d284df1f610ea2398c5d15325f6f60432b 100644
--- a/etc/config/paraview.sh
+++ b/etc/config/paraview.sh
@@ -88,7 +88,7 @@ case "$ParaView_VERSION" in
 esac
 export ParaView_VERSION ParaView_MAJOR
 
-paraviewInstDir=$WM_THIRD_PARTY_DIR/paraview-$ParaView_VERSION
+paraviewInstDir=$WM_THIRD_PARTY_DIR/ParaView-$ParaView_VERSION
 export ParaView_DIR=$WM_THIRD_PARTY_DIR/platforms/$WM_ARCH$WM_COMPILER/paraview-$ParaView_VERSION
 
 # set paths if binaries or source are present
diff --git a/src/OpenFOAM/db/Time/Time.C b/src/OpenFOAM/db/Time/Time.C
index 8e509a738b88b25ae00a6c219e80d2371acc7a9f..e90758dafd1dc70fb12d361815c4d81a6aa56349 100644
--- a/src/OpenFOAM/db/Time/Time.C
+++ b/src/OpenFOAM/db/Time/Time.C
@@ -25,6 +25,7 @@ License
 
 #include "Time.H"
 #include "PstreamReduceOps.H"
+#include "argList.H"
 
 #include <sstream>
 
@@ -215,7 +216,8 @@ Foam::Time::Time
     const fileName& rootPath,
     const fileName& caseName,
     const word& systemName,
-    const word& constantName
+    const word& constantName,
+    const bool enableFunctionObjects
 )
 :
     TimePaths
@@ -259,7 +261,94 @@ Foam::Time::Time
     graphFormat_("raw"),
     runTimeModifiable_(true),
 
-    functionObjects_(*this)
+    functionObjects_(*this, enableFunctionObjects)
+{
+    libs_.open(controlDict_, "libs");
+
+    // Explicitly set read flags on objectRegistry so anything constructed
+    // from it reads as well (e.g. fvSolution).
+    readOpt() = IOobject::MUST_READ_IF_MODIFIED;
+
+    setControls();
+
+    // Time objects not registered so do like objectRegistry::checkIn ourselves.
+    if (runTimeModifiable_)
+    {
+        monitorPtr_.reset
+        (
+            new fileMonitor
+            (
+                regIOobject::fileModificationChecking == inotify
+             || regIOobject::fileModificationChecking == inotifyMaster
+            )
+        );
+
+        // File might not exist yet.
+        fileName f(controlDict_.filePath());
+
+        if (!f.size())
+        {
+            // We don't have this file but would like to re-read it.
+            // Possibly if in master-only reading mode. Use a non-existing
+            // file to keep fileMonitor synced.
+            f = controlDict_.objectPath();
+        }
+
+        controlDict_.watchIndex() = addWatch(f);
+    }
+}
+
+
+Foam::Time::Time
+(
+    const word& controlDictName,
+    const argList& args,
+    const word& systemName,
+    const word& constantName
+)
+:
+    TimePaths
+    (
+        args.rootPath(),
+        args.caseName(),
+        systemName,
+        constantName
+    ),
+
+    objectRegistry(*this),
+
+    libs_(),
+
+    controlDict_
+    (
+        IOobject
+        (
+            controlDictName,
+            system(),
+            *this,
+            IOobject::MUST_READ_IF_MODIFIED,
+            IOobject::NO_WRITE,
+            false
+        )
+    ),
+
+    startTimeIndex_(0),
+    startTime_(0),
+    endTime_(0),
+
+    stopAt_(saEndTime),
+    writeControl_(wcTimeStep),
+    writeInterval_(GREAT),
+    purgeWrite_(0),
+    subCycling_(false),
+
+    writeFormat_(IOstream::ASCII),
+    writeVersion_(IOstream::currentVersion),
+    writeCompression_(IOstream::UNCOMPRESSED),
+    graphFormat_("raw"),
+    runTimeModifiable_(true),
+
+    functionObjects_(*this, !args.optionFound("noFunctionObjects"))
 {
     libs_.open(controlDict_, "libs");
 
@@ -303,7 +392,8 @@ Foam::Time::Time
     const fileName& rootPath,
     const fileName& caseName,
     const word& systemName,
-    const word& constantName
+    const word& constantName,
+    const bool enableFunctionObjects
 )
 :
     TimePaths
@@ -348,7 +438,7 @@ Foam::Time::Time
     graphFormat_("raw"),
     runTimeModifiable_(true),
 
-    functionObjects_(*this)
+    functionObjects_(*this, enableFunctionObjects)
 {
     libs_.open(controlDict_, "libs");
 
@@ -395,7 +485,8 @@ Foam::Time::Time
     const fileName& rootPath,
     const fileName& caseName,
     const word& systemName,
-    const word& constantName
+    const word& constantName,
+    const bool enableFunctionObjects
 )
 :
     TimePaths
@@ -439,7 +530,7 @@ Foam::Time::Time
     graphFormat_("raw"),
     runTimeModifiable_(true),
 
-    functionObjects_(*this)
+    functionObjects_(*this, enableFunctionObjects)
 {
     libs_.open(controlDict_, "libs");
 }
diff --git a/src/OpenFOAM/global/argList/argList.C b/src/OpenFOAM/global/argList/argList.C
index fba0cefe17f0ae0d80b90e03fd5047cf7dd8dc5c..75e129e271480fe0b33eda47e26db7af840c890c 100644
--- a/src/OpenFOAM/global/argList/argList.C
+++ b/src/OpenFOAM/global/argList/argList.C
@@ -64,6 +64,12 @@ Foam::argList::initValidTables::initValidTables()
     );
     validParOptions.set("roots", "(dir1 .. dirN)");
 
+    argList::addBoolOption
+    (
+        "noFunctionObjects",
+        "do not execute functionObjects"
+    );
+
     Pstream::addValidParOptions(validParOptions);
 }
 
diff --git a/src/OpenFOAM/include/createTime.H b/src/OpenFOAM/include/createTime.H
index 057814a8708a767ecdd07470abaef6779136dffe..36fc675dc36acf76061de0263f02eebb90567d2c 100644
--- a/src/OpenFOAM/include/createTime.H
+++ b/src/OpenFOAM/include/createTime.H
@@ -4,9 +4,4 @@
 
     Foam::Info<< "Create time\n" << Foam::endl;
 
-    Foam::Time runTime
-    (
-        Foam::Time::controlDictName,
-        args.rootPath(),
-        args.caseName()
-    );
+    Foam::Time runTime(Foam::Time::controlDictName, args);
diff --git a/src/meshTools/Make/files b/src/meshTools/Make/files
index abf52704b1efc54be683d3ab274123b51defad39..e9b137abc72a3082736b3e24c842d38bbb329438 100644
--- a/src/meshTools/Make/files
+++ b/src/meshTools/Make/files
@@ -91,6 +91,7 @@ $(cellSources)/zoneToCell/zoneToCell.C
 $(cellSources)/sphereToCell/sphereToCell.C
 $(cellSources)/cylinderToCell/cylinderToCell.C
 $(cellSources)/faceZoneToCell/faceZoneToCell.C
+$(cellSources)/cylinderAnnulusToCell/cylinderAnnulusToCell.C
 
 faceSources = sets/faceSources
 $(faceSources)/faceToFace/faceToFace.C
diff --git a/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.C b/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.C
new file mode 100644
index 0000000000000000000000000000000000000000..80ccd4fa9534f2a050766e8aa7657c6cf855c862
--- /dev/null
+++ b/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.C
@@ -0,0 +1,161 @@
+/*---------------------------------------------------------------------------*\
+  =========                 |
+  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
+   \\    /   O peration     |
+    \\  /    A nd           | Copyright (C) 2011-2011 OpenCFD Ltd.
+     \\/     M anipulation  |
+-------------------------------------------------------------------------------
+License
+    This file is part of OpenFOAM.
+
+    OpenFOAM is free software: you can redistribute it and/or modify it
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+    for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
+
+\*---------------------------------------------------------------------------*/
+
+#include "cylinderAnnulusToCell.H"
+#include "polyMesh.H"
+#include "addToRunTimeSelectionTable.H"
+
+// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //
+
+namespace Foam
+{
+    defineTypeNameAndDebug(cylinderAnnulusToCell, 0);
+    addToRunTimeSelectionTable(topoSetSource, cylinderAnnulusToCell, word);
+    addToRunTimeSelectionTable(topoSetSource, cylinderAnnulusToCell, istream);
+}
+
+
+Foam::topoSetSource::addToUsageTable Foam::cylinderAnnulusToCell::usage_
+(
+    cylinderAnnulusToCell::typeName,
+    "\n    Usage: cylinderAnnulusToCell (p1X p1Y p1Z) (p2X p2Y p2Z)"
+    " outerRadius innerRadius\n\n"
+    "    Select all cells with cell centre within bounding cylinder annulus\n\n"
+);
+
+
+// * * * * * * * * * * * * * Private Member Functions  * * * * * * * * * * * //
+
+void Foam::cylinderAnnulusToCell::combine(topoSet& set, const bool add) const
+{
+    const vector axis = p2_ - p1_;
+    const scalar orad2 = sqr(outerRadius_);
+    const scalar irad2 = sqr(innerRadius_);
+    const scalar magAxis2 = magSqr(axis);
+
+    const pointField& ctrs = mesh_.cellCentres();
+
+    forAll(ctrs, cellI)
+    {
+        vector d = ctrs[cellI] - p1_;
+        scalar magD = d & axis;
+
+        if ((magD > 0) && (magD < magAxis2))
+        {
+            scalar d2 = (d & d) - sqr(magD)/magAxis2;
+            if ((d2 < orad2) && (d2 > irad2))
+            {
+                addOrDelete(set, cellI, add);
+            }
+        }
+    }
+}
+
+
+// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
+
+Foam::cylinderAnnulusToCell::cylinderAnnulusToCell
+(
+    const polyMesh& mesh,
+    const vector& p1,
+    const vector& p2,
+    const scalar outerRadius,
+    const scalar innerRadius
+)
+:
+    topoSetSource(mesh),
+    p1_(p1),
+    p2_(p2),
+    outerRadius_(outerRadius),
+    innerRadius_(innerRadius)
+{}
+
+
+Foam::cylinderAnnulusToCell::cylinderAnnulusToCell
+(
+    const polyMesh& mesh,
+    const dictionary& dict
+)
+:
+    topoSetSource(mesh),
+    p1_(dict.lookup("p1")),
+    p2_(dict.lookup("p2")),
+    outerRadius_(readScalar(dict.lookup("outerRadius"))),
+    innerRadius_(readScalar(dict.lookup("innerRadius")))
+{}
+
+
+// Construct from Istream
+Foam::cylinderAnnulusToCell::cylinderAnnulusToCell
+(
+    const polyMesh& mesh,
+    Istream& is
+)
+:
+    topoSetSource(mesh),
+    p1_(checkIs(is)),
+    p2_(checkIs(is)),
+    outerRadius_(readScalar(checkIs(is))),
+    innerRadius_(readScalar(checkIs(is)))
+{}
+
+
+// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //
+
+Foam::cylinderAnnulusToCell::~cylinderAnnulusToCell()
+{}
+
+
+// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
+
+void Foam::cylinderAnnulusToCell::applyToSet
+(
+    const topoSetSource::setAction action,
+    topoSet& set
+) const
+{
+    if ((action == topoSetSource::NEW) || (action == topoSetSource::ADD))
+    {
+        Info<< "    Adding cells with centre within cylinder annulus,"
+            << " with p1 = "
+            << p1_ << ", p2 = " << p2_ << " and outer radius = " << outerRadius_
+        << " and inner radius = " << innerRadius_
+        << endl;
+
+        combine(set, true);
+    }
+    else if (action == topoSetSource::DELETE)
+    {
+        Info<< "    Removing cells with centre within cylinder, with p1 = "
+            << p1_ << ", p2 = " << p2_ << " and outer radius = " << outerRadius_
+        << " and inner radius " << innerRadius_
+        << endl;
+
+        combine(set, false);
+    }
+}
+
+
+// ************************************************************************* //
diff --git a/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.H b/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.H
new file mode 100644
index 0000000000000000000000000000000000000000..f9ab221dda5d426e191c646c9ee44d10d7108929
--- /dev/null
+++ b/src/meshTools/sets/cellSources/cylinderAnnulusToCell/cylinderAnnulusToCell.H
@@ -0,0 +1,138 @@
+/*---------------------------------------------------------------------------*\
+  =========                 |
+  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
+   \\    /   O peration     |
+    \\  /    A nd           | Copyright (C) 2011-2011 OpenCFD Ltd.
+     \\/     M anipulation  |
+-------------------------------------------------------------------------------
+License
+    This file is part of OpenFOAM.
+
+    OpenFOAM is free software: you can redistribute it and/or modify it
+    under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+    for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.
+
+Class
+    Foam::cylinderAnnulusToCell
+
+Description
+    A topoSetSource to select cells based on cell centres inside a
+    cylinder annulus.
+
+SourceFiles
+    cylinderAnnulusToCell.C
+
+\*---------------------------------------------------------------------------*/
+
+#ifndef cylinderAnnulusToCell_H
+#define cylinderAnnulusToCell_H
+
+#include "topoSetSource.H"
+
+// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
+
+namespace Foam
+{
+
+/*---------------------------------------------------------------------------*\
+                       Class cylinderAnnulusToCell Declaration
+\*---------------------------------------------------------------------------*/
+
+class cylinderAnnulusToCell
+:
+    public topoSetSource
+{
+
+    // Private data
+
+        //- Add usage string
+        static addToUsageTable usage_;
+
+        //- First point on cylinder axis
+        vector p1_;
+
+        //- Second point on cylinder axis
+        vector p2_;
+
+        //- Outer Radius
+        scalar outerRadius_;
+
+        //- Inner Radius
+        scalar innerRadius_;
+
+
+    // Private Member Functions
+
+        void combine(topoSet& set, const bool add) const;
+
+
+public:
+
+    //- Runtime type information
+    TypeName("cylinderAnnulusToCell");
+
+
+    // Constructors
+
+        //- Construct from components
+        cylinderAnnulusToCell
+        (
+            const polyMesh& mesh,
+            const vector& p1,
+            const vector& p2,
+            const scalar outerRadius,
+            const scalar innerRadius
+        );
+
+        //- Construct from dictionary
+        cylinderAnnulusToCell
+        (
+            const polyMesh& mesh,
+            const dictionary& dict
+        );
+
+        //- Construct from Istream
+        cylinderAnnulusToCell
+        (
+            const polyMesh& mesh,
+            Istream&
+        );
+
+
+    // Destructor
+    virtual ~cylinderAnnulusToCell();
+
+    // Member Functions
+
+        virtual sourceType setType() const
+        {
+            return CELLSETSOURCE;
+        }
+
+        virtual void applyToSet
+        (
+            const topoSetSource::setAction action,
+            topoSet&
+        ) const;
+
+};
+
+
+// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
+
+} // End namespace Foam
+
+// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
+
+#endif
+
+// ************************************************************************* //
diff --git a/tutorials/basic/potentialFoam/cylinder/Allrun b/tutorials/basic/potentialFoam/cylinder/Allrun
index 219e4473de6710f23bf10ff3db7d8d91118a327b..bb35ba990c2bfba261b2d5aea907a4e78ba0251d 100755
--- a/tutorials/basic/potentialFoam/cylinder/Allrun
+++ b/tutorials/basic/potentialFoam/cylinder/Allrun
@@ -6,6 +6,32 @@ cd ${0%/*} || exit 1    # run from this directory
 
 application=`getApplication`
 
+
+# This case uses the #codeStream which is disabled by default. Enable for
+# just this case.
+MAIN_CONTROL_DICT=`foamEtcFile controlDict`
+if [ -f "$MAIN_CONTROL_DICT" ]
+then
+    echo "Modifying ${MAIN_CONTROL_DICT}"
+    if [ -e ${MAIN_CONTROL_DICT}.org ]
+    then
+        echo "File ${MAIN_CONTROL_DICT}.org already exists"
+        echo "Did Allrun fail in some way and then run again?"
+        exit 1
+    fi
+
+    # Clean up on termination and on Ctrl-C
+    trap 'mv ${MAIN_CONTROL_DICT}.org ${MAIN_CONTROL_DICT} 2>/dev/null; exit 0' \
+        EXIT TERM INT
+    cp ${MAIN_CONTROL_DICT} ${MAIN_CONTROL_DICT}.org
+
+    echo "Enabling allowSystemOperations in ${MAIN_CONTROL_DICT}."
+
+    sed \
+    -e s/"\(allowSystemOperations[ \t]*\)\([0-9]\);"/"\1 1;"/g \
+    ${MAIN_CONTROL_DICT}.org > ${MAIN_CONTROL_DICT}
+fi
+
 cp -r 0.org 0 > /dev/null 2>&1
 runApplication blockMesh
 runApplication $application
diff --git a/tutorials/basic/potentialFoam/pitzDaily/0/U b/tutorials/basic/potentialFoam/pitzDaily/0/U
deleted file mode 100644
index 3aec038c3f95acda8f3743ee774b411cbf43db37..0000000000000000000000000000000000000000
--- a/tutorials/basic/potentialFoam/pitzDaily/0/U
+++ /dev/null
@@ -1,52 +0,0 @@
-/*--------------------------------*- C++ -*----------------------------------*\
-| =========                 |                                                 |
-| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  2.0                                   |
-|   \\  /    A nd           | Web:      www.OpenFOAM.com                      |
-|    \\/     M anipulation  |                                                 |
-\*---------------------------------------------------------------------------*/
-FoamFile
-{
-    version     2.0;
-    format      ascii;
-    class       volVectorField;
-    object      U;
-}
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-dimensions      [0 1 -1 0 0 0 0];
-
-internalField   uniform (0 0 0);
-
-boundaryField
-{
-    inlet           
-    {
-        type            fixedValue;
-        value           uniform (10 0 0);
-    }
-
-    outlet          
-    {
-        type            zeroGradient;
-    }
-
-    upperWall       
-    {
-        type            fixedValue;
-        value           uniform (0 0 0);
-    }
-
-    lowerWall       
-    {
-        type            fixedValue;
-        value           uniform (0 0 0);
-    }
-
-    frontAndBack    
-    {
-        type            empty;
-    }
-}
-
-// ************************************************************************* //
diff --git a/tutorials/basic/potentialFoam/pitzDaily/0/p b/tutorials/basic/potentialFoam/pitzDaily/0/p
deleted file mode 100644
index 86087fe75ff50dd71678a2f96231b24f64630611..0000000000000000000000000000000000000000
--- a/tutorials/basic/potentialFoam/pitzDaily/0/p
+++ /dev/null
@@ -1,50 +0,0 @@
-/*--------------------------------*- C++ -*----------------------------------*\
-| =========                 |                                                 |
-| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  2.0                                   |
-|   \\  /    A nd           | Web:      www.OpenFOAM.com                      |
-|    \\/     M anipulation  |                                                 |
-\*---------------------------------------------------------------------------*/
-FoamFile
-{
-    version     2.0;
-    format      ascii;
-    class       volScalarField;
-    object      p;
-}
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-dimensions      [0 2 -2 0 0 0 0];
-
-internalField   uniform 0;
-
-boundaryField
-{
-    inlet           
-    {
-        type            zeroGradient;
-    }
-
-    outlet          
-    {
-        type            fixedValue;
-        value           uniform 0;
-    }
-
-    upperWall       
-    {
-        type            zeroGradient;
-    }
-
-    lowerWall       
-    {
-        type            zeroGradient;
-    }
-
-    frontAndBack    
-    {
-        type            empty;
-    }
-}
-
-// ************************************************************************* //
diff --git a/tutorials/basic/potentialFoam/Allclean b/tutorials/basic/potentialFoam/pitzDaily/Allclean
similarity index 50%
rename from tutorials/basic/potentialFoam/Allclean
rename to tutorials/basic/potentialFoam/pitzDaily/Allclean
index b81c740007908499f8ef2e3d698009099c41e46e..d16400a94f636d461b62f6f909c2d64d7e29c335 100755
--- a/tutorials/basic/potentialFoam/Allclean
+++ b/tutorials/basic/potentialFoam/pitzDaily/Allclean
@@ -4,22 +4,8 @@ cd ${0%/*} || exit 1    # run from this directory
 # Source tutorial clean functions
 . $WM_PROJECT_DIR/bin/tools/CleanFunctions
 
-(
-    cd cylinder || exit
+rm -rf 0 > /dev/null 2>&1
 
-    cleanCase
-    rm -rf 0 > /dev/null 2>&1
-    cp -r 0.org 0
-    wclean analyticalCylinder
-)
-
-
-(
-    cd pitzDaily || exit
-
-    cleanCase
-    rm -rf 0 > /dev/null 2>&1
-    cp -r 0.org 0
-)
+cleanCase
 
 # ----------------------------------------------------------------- end-of-file
diff --git a/tutorials/basic/potentialFoam/pitzDaily/Allrun b/tutorials/basic/potentialFoam/pitzDaily/Allrun
index 86fa0fdc4d690ec147a12c56059637bcf3d39e0d..219e4473de6710f23bf10ff3db7d8d91118a327b 100755
--- a/tutorials/basic/potentialFoam/pitzDaily/Allrun
+++ b/tutorials/basic/potentialFoam/pitzDaily/Allrun
@@ -6,6 +6,7 @@ cd ${0%/*} || exit 1    # run from this directory
 
 application=`getApplication`
 
+cp -r 0.org 0 > /dev/null 2>&1
 runApplication blockMesh
 runApplication $application
 runApplication streamFunction
diff --git a/tutorials/incompressible/simpleFoam/motorBike/Allrun b/tutorials/incompressible/simpleFoam/motorBike/Allrun
index ed9f842fed766d29d015e6399fee07936b9bf0c4..474f9cfd948a0b48c12095943bc979e8efc82550 100755
--- a/tutorials/incompressible/simpleFoam/motorBike/Allrun
+++ b/tutorials/incompressible/simpleFoam/motorBike/Allrun
@@ -7,5 +7,5 @@ cp -r 0.org 0 > /dev/null 2>&1
 runApplication blockMesh
 runApplication snappyHexMesh -overwrite
 
-runApplication potentialFoam -writep
+runApplication potentialFoam -noFunctionObjects -writep
 runApplication `getApplication`
diff --git a/tutorials/mesh/snappyHexMesh/Allrun b/tutorials/mesh/snappyHexMesh/Allrun
index d15026b3b0d6c81a2b063b40bf86528de5216406..057d8bf8dd76dd03931ef34eada94930c3945ff6 100755
--- a/tutorials/mesh/snappyHexMesh/Allrun
+++ b/tutorials/mesh/snappyHexMesh/Allrun
@@ -1,6 +1,12 @@
 #!/bin/sh
 cd ${0%/*} || exit 1    # run from this directory
 
+                                                                                                                                                                                                                                                                                                                          
+(                                                                                                                                                                                                                                                                                                                         
+    cd flange || exit                                                                                                                                                                                                                                                                                                   
+    ./Allrun                                                                                                                                                                                                                                                                                                              
+)                                                                                                                                                                                                                                                                                                                         
+                                                                                                                                                                                                                                                                                                                          
 exit 0
 
 # These cases are links to solver test cases and are run when the Allrun
diff --git a/src/OpenFOAM/db/Time/Time.H b/src/OpenFOAM/db/Time/Time.H
index b9da549895fafc7975d4eb92af4bdf023ef61b8d..216ae129858ab3ecac0605be5ec52f3a89c65a68 100644
--- a/src/OpenFOAM/db/Time/Time.H
+++ b/src/OpenFOAM/db/Time/Time.H
@@ -57,6 +57,8 @@ SourceFiles
 
 namespace Foam
 {
+// Forward declaration of classes
+class argList;
 
 /*---------------------------------------------------------------------------*\
                              Class Time Declaration
@@ -184,14 +186,24 @@ public:
 
     // Constructors
 
-        //- Construct given name, rootPath and casePath
+        //- Construct given name of dictionary to read and argument list
+        Time
+        (
+            const word& name,
+            const argList& args,
+            const word& systemName = "system",
+            const word& constantName = "constant"
+        );
+
+        //- Construct given name of dictionary to read, rootPath and casePath
         Time
         (
             const word& name,
             const fileName& rootPath,
             const fileName& caseName,
             const word& systemName = "system",
-            const word& constantName = "constant"
+            const word& constantName = "constant",
+            const bool enableFunctionObjects = true
         );
 
         //- Construct given dictionary, rootPath and casePath
@@ -201,7 +213,8 @@ public:
             const fileName& rootPath,
             const fileName& caseName,
             const word& systemName = "system",
-            const word& constantName = "constant"
+            const word& constantName = "constant",
+            const bool enableFunctionObjects = true
         );
 
         //- Construct given endTime, rootPath and casePath
@@ -210,7 +223,8 @@ public:
             const fileName& rootPath,
             const fileName& caseName,
             const word& systemName = "system",
-            const word& constantName = "constant"
+            const word& constantName = "constant",
+            const bool enableFunctionObjects = true
         );
 
 